@@ -217,6 +217,9 @@ void File_Lxf::Streams_Fill()
 //---------------------------------------------------------------------------
 void File_Lxf::Streams_Fill_PerStream(File__Analyze* Parser, stream_t Container_StreamKind, size_t Parser_Pos, int8u Format)
 {
+    if (Format!=(int8u)-1)
+        Fill(Container_StreamKind, Container_StreamKind==Stream_Video?0:Parser_Pos, Fill_Parameter(Container_StreamKind, Generic_CodecID), Format);
+
     if (Parser==NULL)
         return;
 
@@ -264,8 +267,6 @@ void File_Lxf::Streams_Fill_PerStream(File__Analyze* Parser, stream_t Container_
                     }
         #endif //MEDIAINFO_DEMUX
     }
-    if (Format!=(int8u)-1)
-        Fill(Container_StreamKind, Container_StreamKind==Stream_Video?0:Parser_Pos, Fill_Parameter(Container_StreamKind, Generic_CodecID), Format);
     if (Container_StreamKind==Stream_Video)
         for (size_t Pos=Count_Get(Stream_Audio)-Parser->Count_Get(Stream_Audio); Pos<Count_Get(Stream_Audio); Pos++)
             Fill(Stream_Audio, Pos, Audio_MuxingMode, Parser->Retrieve(Stream_General, 0, General_Format));
@@ -524,6 +525,7 @@ size_t File_Lxf::Read_Buffer_Seek (size_t Method, int64u Value, int64u)
                         float64 TimeStamp=((float64)Value)/FrameRate;
                         Value=float64_int64s(TimeStamp*1000000000); // In nanoseconds
                     }
+                    return 1;
         case 2  :   //Timestamp
                     {
                     if (Value!=(int64u)-1)
@@ -909,7 +911,7 @@ void File_Lxf::Header()
 
     Info_General_StreamSize=0x48+Element_Size;
 
-    #if MEDIAINFO_DEMUX
+    #if MEDIAINFO_DEMUX && MEDIAINFO_NEXTPACKET
         if (Config->NextPacket_Get() && Config->Event_CallBackFunction_IsSet())
             Config->Demux_EventWasSent=true; //First set is to indicate the user that header is parsed
     #endif //MEDIAINFO_DEMUX
@@ -1408,7 +1410,7 @@ void File_Lxf::Audio_Stream(size_t Pos)
         #ifdef MEDIAINFO_SMPTEST0337_YES
         {
             File_SmpteSt0337* Parser=new File_SmpteSt0337;
-            Parser->Container_Bits=SampleSize;
+            Parser->BitDepth=SampleSize;
             Parser->Endianness='L';
             Parser->Aligned=true;
 
@@ -1550,7 +1552,7 @@ void File_Lxf::Audio_Stream(size_t Pos)
         {
             if (!Audios[Pos].Parsers[Pos2]->Status[IsAccepted] && Audios[Pos].Parsers[Pos2]->Status[IsFinished])
             {
-                delete *(Audios[Pos].Parsers.begin()+Pos2);
+                delete static_cast<MediaInfoLib::File__Analyze*>(*(Audios[Pos].Parsers.begin()+Pos2));
                 Audios[Pos].Parsers.erase(Audios[Pos].Parsers.begin()+Pos2);
                 Pos2--;
             }
@@ -1560,7 +1562,7 @@ void File_Lxf::Audio_Stream(size_t Pos)
                 for (size_t Pos3=0; Pos3<Audios[Pos].Parsers.size(); Pos3++)
                 {
                     if (Pos3!=Pos2)
-                        delete *(Audios[Pos].Parsers.begin()+Pos3);
+                        delete static_cast<MediaInfoLib::File__Analyze*>(*(Audios[Pos].Parsers.begin()+Pos3));
                 }
                 Audios[Pos].Parsers.clear();
                 Audios[Pos].Parsers.push_back(Parser);
@@ -1841,7 +1843,7 @@ void File_Lxf::Video_Stream_2()
         {
             if (!Videos[2].Parsers[Pos2]->Status[IsAccepted] && Videos[2].Parsers[Pos2]->Status[IsFinished])
             {
-                delete *(Videos[2].Parsers.begin()+Pos2);
+                delete static_cast<MediaInfoLib::File__Analyze*>(*(Videos[2].Parsers.begin()+Pos2));
                 Videos[2].Parsers.erase(Videos[2].Parsers.begin()+Pos2);
                 Pos2--;
             }
@@ -1851,7 +1853,7 @@ void File_Lxf::Video_Stream_2()
                 for (size_t Pos3=0; Pos3<Videos[2].Parsers.size(); Pos3++)
                 {
                     if (Pos3!=Pos2)
-                        delete *(Videos[2].Parsers.begin()+Pos3);
+                        delete static_cast<MediaInfoLib::File__Analyze*>(*(Videos[2].Parsers.begin()+Pos3));
                 }
                 Videos[2].Parsers.clear();
                 Videos[2].Parsers.push_back(Parser);
